Exception: CSI::CodeInvalid
- Defined in:
- lib/errors.rb,
lib/csi/errors.rb
Overview
Raised when trying to find an invalid code - a code that does not exist, or is not a String value e.g.
CSI::naics("1337")
# => CSI::CodeInvalid
CSI::sic(1337)
# => CSI::CodeInvalid